@@ -1,36 +1,42 @@
-# -*- coding=utf-8 -*-
-from __future__ import absolute_import, print_function
-
 import ast
 import atexit
 import configparser
 import contextlib
-import importlib
-import operator
 import os
 import shutil
+import subprocess as sp
 import sys
 from collections.abc import Iterable, Mapping
-from functools import lru_cache, partial
+from contextlib import ExitStack
+from functools import lru_cache
+from os import scandir
 from pathlib import Path
 from urllib.parse import parse_qs, urlparse, urlunparse
 from weakref import finalize
 
 import attr
-import pep517.envbuild
-import pep517.wrappers
 from distlib.wheel import Wheel
-from packaging.markers import Marker
-from packaging.specifiers import SpecifierSet
-from packaging.version import parse
-from pip_shims.utils import call_function_with_correct_args
+from pep517 import envbuild, wrappers
+from pip._internal.network.download import Downloader
+from pip._internal.utils.temp_dir import global_tempdir_manager
+from pip._internal.utils.urls import url_to_path
+from pip._vendor.packaging.markers import Marker
+from pip._vendor.packaging.specifiers import SpecifierSet
+from pip._vendor.packaging.version import parse
+from pip._vendor.pkg_resources import (
+    PathMetadata,
+    Requirement,
+    distributions_from_metadata,
+    find_distributions,
+)
 from platformdirs import user_cache_dir
 from vistir.contextmanagers import cd, temp_path
-from vistir.misc import run
-from vistir.path import create_tracked_tempdir, ensure_mkdir_p, mkdir_p, rmtree
+from vistir.path import create_tracked_tempdir, rmtree
 
 from ..environment import MYPY_RUNNING
 from ..exceptions import RequirementError
+from ..utils import get_pip_command
+from .old_pip_utils import old_unpack_url
 from .utils import (
     get_default_pyproject_backend,
     get_name_variants,
@@ -40,20 +46,6 @@ from .utils import (
     strip_extras_markers_from_requirement,
 )
 
-try:
-    import pkg_resources.extern.packaging.requirements as pkg_resources_requirements
-except ModuleNotFoundError:
-    pkg_resources_requirements = None
-
-try:
-    from setuptools.dist import Distribution, distutils
-except ImportError:
-    import distutils
-    from distutils.core import Distribution
-
-from contextlib import ExitStack
-from os import scandir
-
 if MYPY_RUNNING:
     from typing import (
         Any,
@@ -70,11 +62,12 @@ if MYPY_RUNNING:
         Union,
     )
 
-    import requests
-    from packaging.requirements import Requirement as PackagingRequirement
-    from pip_shims.shims import InstallRequirement, PackageFinder
-    from pkg_resources import DistInfoDistribution, EggInfoDistribution, PathMetadata
-    from pkg_resources import Requirement as PkgResourcesRequirement
+    from pip._internal.index.package_finder import PackageFinder
+    from pip._internal.req.req_install import InstallRequirement
+    from pip._vendor.packaging.requirements import Requirement as PackagingRequirement
+    from pip._vendor.pkg_resources import DistInfoDistribution, EggInfoDistribution
+    from pip._vendor.requests import Session
+    from setuptools.dist import Distribution
 
     TRequirement = TypeVar("TRequirement")
     RequirementType = TypeVar(
@@ -101,19 +94,11 @@ def pep517_subprocess_runner(cmd, cwd=None, extra_environ=None):
     if extra_environ:
         env.update(extra_environ)
 
-    run(
-        cmd,
-        cwd=cwd,
-        env=env,
-        block=True,
-        combine_stderr=True,
-        return_object=False,
-        write_to_stdout=False,
-        nospin=True,
-    )
+    cmd_as_str = " ".join(cmd)
+    sp.run(cmd_as_str, cwd=cwd, env=env, stdout=sp.PIPE, stderr=sp.STDOUT, shell=True)
 
 
-class BuildEnv(pep517.envbuild.BuildEnvironment):
+class BuildEnv(envbuild.BuildEnvironment):
     def pip_install(self, reqs):
         cmd = [
             sys.executable,
@@ -124,17 +109,11 @@ class BuildEnv(pep517.envbuild.BuildEnvironment):
             "--prefix",
             self.path,
         ] + list(reqs)
-        run(
-            cmd,
-            block=True,
-            combine_stderr=True,
-            return_object=False,
-            write_to_stdout=False,
-            nospin=True,
-        )
+
+        sp.run(cmd, shell=True, stderr=sp.PIPE, stdout=sp.PIPE)
 
 
-class HookCaller(pep517.wrappers.Pep517HookCaller):
+class HookCaller(wrappers.Pep517HookCaller):
     def __init__(self, source_dir, build_backend, backend_path=None):
         super().__init__(source_dir, build_backend, backend_path=backend_path)
         self.source_dir = os.path.abspath(source_dir)
@@ -142,7 +121,7 @@ class HookCaller(pep517.wrappers.Pep517HookCaller):
         self._subprocess_runner = pep517_subprocess_runner
         if backend_path:
             backend_path = [
-                pep517.wrappers.norm_and_check(self.source_dir, p) for p in backend_path
+                wrappers.norm_and_check(self.source_dir, p) for p in backend_path
             ]
         self.backend_path = backend_path
 
@@ -155,9 +134,7 @@ def make_base_requirements(reqs):
     for req in reqs:
         if isinstance(req, BaseRequirement):
             requirements.add(req)
-        elif pkg_resources_requirements is not None and isinstance(
-            req, pkg_resources_requirements.Requirement
-        ):
+        elif isinstance(req, Requirement):
             requirements.add(BaseRequirement.from_req(req))
         elif req and isinstance(req, str) and not req.startswith("#"):
             requirements.add(BaseRequirement.from_string(req))
@@ -545,26 +522,6 @@ def parse_setup_cfg(path: str) -> "Dict[str, Any]":
     return SetupReader.read_setup_cfg(Path(path))
 
 
-@contextlib.contextmanager
-def _suppress_distutils_logs():
-    # type: () -> Generator[None, None, None]
-    """Hack to hide noise generated by `setup.py develop`.
-
-    There isn't a good way to suppress them now, so let's monky-patch.
-    See https://bugs.python.org/issue25392.
-    """
-
-    f = distutils.log.Log._log
-
-    def _log(log, level, msg, args):
-        if level >= distutils.log.ERROR:
-            f(log, level, msg, args)
-
-    distutils.log.Log._log = _log
-    yield
-    distutils.log.Log._log = f
-
-
 def build_pep517(source_dir, build_dir, config_settings=None, dist_type="wheel"):
     if config_settings is None:
         config_settings = {}
@@ -584,7 +541,6 @@ def build_pep517(source_dir, build_dir, config_settings=None, dist_type="wheel")
         return build_fn(build_dir, config_settings)
 
 
-@ensure_mkdir_p(mode=0o775)
 def _get_src_dir(root):
     # type: (AnyStr) -> AnyStr
     src = os.environ.get("PIP_SRC")
@@ -598,13 +554,14 @@ def _get_src_dir(root):
         src_dir = create_tracked_tempdir(prefix="requirementslib-", suffix="-src")
     else:
         src_dir = os.path.join(root, "src")
+
+    os.makedirs(src_dir, mode=0o775)
     return src_dir
 
 
 @lru_cache()
 def ensure_reqs(reqs):
-    # type: (List[Union[S, PkgResourcesRequirement]]) -> List[PkgResourcesRequirement]
-    import pkg_resources
+    # type: (List[Union[S, Requirement]]) -> List[Requirement]
 
     if not isinstance(reqs, Iterable):
         raise TypeError("Expecting an Iterable, got %r" % reqs)
@@ -613,7 +570,7 @@ def ensure_reqs(reqs):
         if not req:
             continue
         if isinstance(req, str):
-            req = pkg_resources.Requirement.parse("{0}".format(str(req)))
+            req = Requirement.parse("{0}".format(str(req)))
         # req = strip_extras_markers_from_requirement(req)
         new_reqs.append(req)
     return new_reqs
@@ -639,10 +596,10 @@ def _prepare_wheel_building_kwargs(
 ):
     # type: (...) -> Dict[STRING_TYPE, STRING_TYPE]
     download_dir = os.path.join(CACHE_DIR, "pkgs")  # type: STRING_TYPE
-    mkdir_p(download_dir)
+    os.makedirs(download_dir, exist_ok=True)
 
     wheel_download_dir = os.path.join(CACHE_DIR, "wheels")  # type: STRING_TYPE
-    mkdir_p(wheel_download_dir)
+    os.makedirs(wheel_download_dir, exist_ok=True)
     if src_dir is None:
         if editable and src_root is not None:
             src_dir = src_root
@@ -749,13 +706,12 @@ def find_distinfo(target, pkg_name=None):
 
 def get_distinfo_dist(path, pkg_name=None):
     # type: (S, Optional[S]) -> Optional[DistInfoDistribution]
-    import pkg_resources
 
     dist_dir = next(iter(find_distinfo(path, pkg_name=pkg_name)), None)
     if dist_dir is not None:
         metadata_dir = dist_dir.path
         base_dir = os.path.dirname(metadata_dir)
-        dist = next(iter(pkg_resources.find_distributions(base_dir)), None)
+        dist = next(iter(find_distributions(base_dir)), None)
         if dist is not None:
             return dist
     return None
@@ -763,14 +719,13 @@ def get_distinfo_dist(path, pkg_name=None):
 
 def get_egginfo_dist(path, pkg_name=None):
     # type: (S, Optional[S]) -> Optional[EggInfoDistribution]
-    import pkg_resources
 
     egg_dir = next(iter(find_egginfo(path, pkg_name=pkg_name)), None)
     if egg_dir is not None:
         metadata_dir = egg_dir.path
         base_dir = os.path.dirname(metadata_dir)
-        path_metadata = pkg_resources.PathMetadata(base_dir, metadata_dir)
-        dist_iter = pkg_resources.distributions_from_metadata(path_metadata.egg_info)
+        path_metadata = PathMetadata(base_dir, metadata_dir)
+        dist_iter = distributions_from_metadata(path_metadata.egg_info)
         dist = next(iter(dist_iter), None)
         if dist is not None:
             return dist
@@ -847,7 +802,7 @@ def get_metadata_from_dist(dist):
         dep_map = dist._build_dep_map()
     except Exception:
         dep_map = {}
-    deps = []  # type: List[PkgResourcesRequirement]
+    deps = []  # type: List[Requirement]
     extras = {}
     for k in dep_map.keys():
         if k is None:
@@ -901,7 +856,7 @@ def run_setup(script_path, egg_base=None):
     target_cwd = os.path.dirname(os.path.abspath(script_path))
     if egg_base is None:
         egg_base = os.path.join(target_cwd, "reqlib-metadata")
-    with temp_path(), cd(target_cwd), _suppress_distutils_logs():
+    with temp_path(), cd(target_cwd):
         # This is for you, Hynek
         # see https://github.com/hynek/environ_config/blob/69b1c8a/setup.py
         args = ["egg_info"]
@@ -923,13 +878,12 @@ def run_setup(script_path, egg_base=None):
         # We couldn't import everything needed to run setup
         except Exception:
             python = os.environ.get("PIP_PYTHON_PATH", sys.executable)
-            out, _ = run(
+
+            sp.run(
                 [python, "setup.py"] + args,
                 cwd=target_cwd,
-                block=True,
-                combine_stderr=False,
-                return_object=False,
-                nospin=True,
+                stdout=sp.PIPE,
+                stderr=sp.PIPE,
             )
         finally:
             _setup_stop_after = None
@@ -944,18 +898,18 @@ class BaseRequirement(object):
     name = attr.ib(default="", eq=True, order=True)  # type: STRING_TYPE
     requirement = attr.ib(
         default=None, eq=True, order=True
-    )  # type: Optional[PkgResourcesRequirement]
+    )  # type: Optional[Requirement]
 
     def __str__(self):
         # type: () -> S
         return "{0}".format(str(self.requirement))
 
     def as_dict(self):
-        # type: () -> Dict[STRING_TYPE, Optional[PkgResourcesRequirement]]
+        # type: () -> Dict[STRING_TYPE, Optional[Requirement]]
         return {self.name: self.requirement}
 
     def as_tuple(self):
-        # type: () -> Tuple[STRING_TYPE, Optional[PkgResourcesRequirement]]
+        # type: () -> Tuple[STRING_TYPE, Optional[Requirement]]
         return (self.name, self.requirement)
 
     @classmethod
@@ -969,7 +923,7 @@ class BaseRequirement(object):
     @classmethod
     @lru_cache()
     def from_req(cls, req):
-        # type: (PkgResourcesRequirement) -> BaseRequirement
+        # type: (Requirement) -> BaseRequirement
         name = None
         key = getattr(req, "key", None)
         name = getattr(req, "name", None)
@@ -1502,19 +1456,17 @@ build-backend = "{1}"
     @classmethod
     @lru_cache()
     def from_ireq(cls, ireq, subdir=None, finder=None, session=None):
-        # type: (InstallRequirement, Optional[AnyStr], Optional[PackageFinder], Optional[requests.Session]) -> Optional[SetupInfo]
-        import pip_shims.shims
-
+        # type: (InstallRequirement, Optional[AnyStr], Optional[PackageFinder], Optional[Session]) -> Optional[SetupInfo]
         if not ireq.link:
             return None
         if ireq.link.is_wheel:
             return None
         stack = ExitStack()
         if not session:
-            cmd = pip_shims.shims.InstallCommand()
+            cmd = get_pip_command()
             options, _ = cmd.parser.parse_args([])
             session = cmd._build_session(options)
-        stack.enter_context(pip_shims.shims.global_tempdir_manager())
+        stack.enter_context(global_tempdir_manager())
         vcs, uri = split_vcs_method_from_uri(ireq.link.url_without_fragment)
         parsed = urlparse(uri)
         if "file" in parsed.scheme:
@@ -1529,19 +1481,17 @@ build-backend = "{1}"
             is_file = True
             if "file:/" in uri and "file:///" not in uri:
                 uri = uri.replace("file:/", "file:///")
-            path = pip_shims.shims.url_to_path(uri)
+            path = url_to_path(uri)
         kwargs = _prepare_wheel_building_kwargs(ireq)
         is_artifact_or_vcs = getattr(
             ireq.link, "is_vcs", getattr(ireq.link, "is_artifact", False)
         )
         is_vcs = True if vcs else is_artifact_or_vcs
-
+        download_dir = None
         if not (ireq.editable and is_file and is_vcs):
             if ireq.is_wheel:
-                only_download = True
                 download_dir = kwargs["wheel_download_dir"]
             else:
-                only_download = False
                 download_dir = kwargs["download_dir"]
         elif path is not None and os.path.isdir(path):
             raise RequirementError(
@@ -1562,32 +1512,19 @@ build-backend = "{1}"
                 "autodelete": False,
                 "parallel_builds": True,
             }
-            call_function_with_correct_args(build_location_func, **build_kwargs)
+            build_location_func(**build_kwargs)
             ireq.ensure_has_source_dir(kwargs["src_dir"])
-            try:  # Support for pip >= 21.1
-                from pip._internal.network.download import Downloader
-
-                from requirementslib.models.old_pip_utils import old_unpack_url
-
-                location = None
-                if getattr(ireq, "source_dir", None):
-                    location = ireq.source_dir
-                old_unpack_url(
-                    link=ireq.link,
-                    location=location,
-                    download=Downloader(session, "off"),
-                    verbosity=1,
-                    download_dir=download_dir,
-                    hashes=ireq.hashes(True),
-                )
-            except ImportError:
-                pip_shims.shims.shim_unpack(
-                    download_dir=download_dir,
-                    ireq=ireq,
-                    only_download=only_download,
-                    session=session,
-                    hashes=ireq.hashes(False),
-                )
+            location = None
+            if getattr(ireq, "source_dir", None):
+                location = ireq.source_dir
+            old_unpack_url(
+                link=ireq.link,
+                location=location,
+                download=Downloader(session, "off"),
+                verbosity=1,
+                download_dir=download_dir,
+                hashes=ireq.hashes(True),
+            )
         created = cls.create(
             ireq.source_dir, subdirectory=subdir, ireq=ireq, kwargs=kwargs, stack=stack
         )
